@@ -19,4 +19,9 @@ def filepath_generator(array_filepath, container, array_name, ctx=None):
         result = PosixArrayPath(array_filepath, array_name)
     elif container is not None:
         result = AzureArrayPath(container, array_name, ctx=ctx)
-    return result
\ No newline at end of file
+    return result
+
+
+def fillnan(xi, y0, diff):
+    """A simple linear 1D interpolator."""
+    return y0 + (xi * diff)
